@@ -2,9 +2,8 @@ import asyncio
 import aiosqlite
 
 
-class SQLite:
-    def __init__(self, filename):
-        self.filename = filename
+class Synchronizer:
+    def __init__(self):
         self.is_open = True
 
     def open(self):
@@ -20,6 +19,16 @@ class SQLite:
     async def __aexit__(self, *args, **kwargs):
         self.open()
 
+    async def wait_for_opening(self):
+        while not self.is_open:
+            await asyncio.sleep(0.2)
+
+
+class SQLite(Synchronizer):
+    def __init__(self, filename):
+        super().__init__()
+        self.filename = filename
+
     async def execute(self, query):
         async with aiosqlite.connect(self.filename) as db:
             async with db.execute(query) as cursor:
@@ -27,6 +36,8 @@ class SQLite:
                 await db.commit()
                 return result
 
-    async def wait_for_opening(self):
-        while not self.is_open:
-            await asyncio.sleep(0.5)
+
+class Variable(Synchronizer):
+    def __init__(self, value):
+        super().__init__()
+        self.object = value
